@@ -22,7 +22,7 @@ class AbstractReader(object):
             setattr(self, k, kwargs[k])
         return self
 
-    def getMibVariants(self, mibname):
+    def getMibVariants(self, mibname, **options):
         filenames = []
 
         if self.originalMatching:
@@ -45,7 +45,8 @@ class AbstractReader(object):
                 filenames.append(suffixed.upper())
                 filenames.append(suffixed.lower())
 
-        return ((x, x + y) for x in filenames for y in self.exts)
+        return ((x, x + y) for x in filenames
+                for y in options.get('exts', self.exts))
 
-    def getData(self, filename):
+    def getData(self, filename, **options):
         raise NotImplementedError()
